@@ -25,7 +25,6 @@ from oslo_config import cfg
 from oslo_log import log as logging
 from voluptuous import All
 from voluptuous import In
-from voluptuous import Invalid
 from voluptuous import Length
 from voluptuous import Range
 from voluptuous import Required
@@ -40,24 +39,6 @@ LOG = logging.getLogger(__name__)
 
 COLLECTOR_GNOCCHI_OPTS = 'collector_gnocchi'
 
-
-def GnocchiMetricDict(value):
-    if isinstance(value, dict) and len(value.keys()) > 0:
-        return value
-    if isinstance(value, list) and len(value) > 0:
-        for v in value:
-            if not (isinstance(v, dict) and len(v.keys()) > 0):
-                raise Invalid("Not a dict with at least one key or a "
-                              "list with at least one dict with at "
-                              "least one key. Provided value: %s" % value)
-        return value
-    raise Invalid("Not a dict with at least one key or a "
-                  "list with at least one dict with at "
-                  "least one key. Provided value: %s" % value)
-
-
-GNOCCHI_CONF_SCHEMA = {Required('metrics'): GnocchiMetricDict}
-
 collector_gnocchi_opts = [
     cfg.StrOpt(
         'gnocchi_auth_type',
@@ -202,30 +183,18 @@ class GnocchiCollector(collector.BaseCollector):
         """Check metrics configuration
 
         """
-        conf = Schema(GNOCCHI_CONF_SCHEMA)(conf)
-        conf = copy.deepcopy(conf)
-        scope_key = CONF.collect.scope_key
+        conf = collector.BaseCollector.check_configuration(conf)
+
         metric_schema = Schema(collector.METRIC_BASE_SCHEMA).extend(
             GNOCCHI_EXTRA_SCHEMA)
 
         output = {}
-        for metric_name, metric in conf['metrics'].items():
-            if not isinstance(metric, list):
-                metric = [metric]
-            for m in metric:
-                met = metric_schema(m)
-                m.update(met)
-                if scope_key not in m['groupby']:
-                    m['groupby'].append(scope_key)
-                if met['extra_args']['resource_key'] not in m['groupby']:
-                    m['groupby'].append(met['extra_args']['resource_key'])
+        for metric_name, metric in conf.items():
+            met = metric_schema(metric)
+            if met['extra_args']['resource_key'] not in met['groupby']:
+                met['groupby'].append(met['extra_args']['resource_key'])
 
-                names = [metric_name]
-                alt_name = met.get('alt_name')
-                if alt_name is not None:
-                    names.append(alt_name)
-                new_metric_name = "@#".join(names)
-                output[new_metric_name] = m
+            output[metric_name] = met
 
         return output
 
