@@ -13,10 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 #
-# @author: Stéphane Albert
-#
 import pecan
-import six
 import wsmeext.pecan as wsme_pecan
 
 from cloudkitty.api.v1 import types as ck_types
@@ -47,7 +44,7 @@ class HashMapThresholdsController(rating.RatingRestControllerBase):
                 uuid=threshold_id)
             return group_models.Group(**group_db.export_model())
         except db_api.ThresholdHasNoGroup as e:
-            pecan.abort(404, six.text_type(e))
+            pecan.abort(404, e.args[0])
 
     @wsme_pecan.wsexpose(threshold_models.ThresholdCollection,
                          ck_types.UuidType(),
@@ -106,7 +103,7 @@ class HashMapThresholdsController(rating.RatingRestControllerBase):
             return threshold_models.Threshold(
                 **threshold_db.export_model())
         except db_api.NoSuchThreshold as e:
-            pecan.abort(404, six.text_type(e))
+            pecan.abort(404, e.args[0])
 
     @wsme_pecan.wsexpose(threshold_models.Threshold,
                          body=threshold_models.Threshold,
@@ -133,9 +130,9 @@ class HashMapThresholdsController(rating.RatingRestControllerBase):
             return threshold_models.Threshold(
                 **threshold_db.export_model())
         except db_api.ThresholdAlreadyExists as e:
-            pecan.abort(409, six.text_type(e))
+            pecan.abort(409, e.args[0])
         except db_api.ClientHashMapError as e:
-            pecan.abort(400, six.text_type(e))
+            pecan.abort(400, e.args[0])
 
     @wsme_pecan.wsexpose(None,
                          ck_types.UuidType(),
@@ -158,10 +155,12 @@ class HashMapThresholdsController(rating.RatingRestControllerBase):
                 group_id=threshold.group_id,
                 tenant_id=threshold.tenant_id)
             pecan.response.headers['Location'] = pecan.request.path
+        except db_api.ThresholdAlreadyExists as e:
+            pecan.abort(409, e.args[0])
         except db_api.NoSuchThreshold as e:
-            pecan.abort(404, six.text_type(e))
+            pecan.abort(404, e.args[0])
         except db_api.ClientHashMapError as e:
-            pecan.abort(400, six.text_type(e))
+            pecan.abort(400, e.args[0])
 
     @wsme_pecan.wsexpose(None,
                          ck_types.UuidType(),
@@ -175,4 +174,4 @@ class HashMapThresholdsController(rating.RatingRestControllerBase):
         try:
             hashmap.delete_threshold(uuid=threshold_id)
         except db_api.NoSuchThreshold as e:
-            pecan.abort(404, six.text_type(e))
+            pecan.abort(404, e.args[0])
