@@ -40,8 +40,8 @@ def create_table(is_old=False):
         sa.Column('cost', sa.Numeric(precision=20, scale=8), nullable=False),
         sa.Column(
             'map_type',
-            sa.Enum('flat', 'rate', name='enum_map_type'),
-            nullable=False),
+            sa.Enum('flat', 'rate', name='enum_map_type',
+                    create_constraint=True), nullable=False),
         sa.Column('service_id', sa.Integer(), nullable=True),
         sa.Column('field_id', sa.Integer(), nullable=True),
         sa.Column('group_id', sa.Integer(), nullable=True),
@@ -71,10 +71,10 @@ def upgrade():
         if dialect != 'postgresql':
             with op.batch_alter_table('hashmap_thresholds') as batch_op:
                 batch_op.drop_constraint(
-                    u'uniq_field_mapping',
+                    'uniq_field_mapping',
                     type_='unique')
                 batch_op.drop_constraint(
-                    u'uniq_service_mapping',
+                    'uniq_service_mapping',
                     type_='unique')
                 batch_op.create_unique_constraint(
                     'uniq_field_threshold',
@@ -95,11 +95,11 @@ def upgrade():
             op.rename_table('tmig_hashmap_thresholds', 'hashmap_thresholds')
         else:
             op.drop_constraint(
-                u'uniq_field_mapping',
+                'uniq_field_mapping',
                 'hashmap_thresholds',
                 type_='unique')
             op.drop_constraint(
-                u'uniq_service_mapping',
+                'uniq_service_mapping',
                 'hashmap_thresholds',
                 type_='unique')
             op.create_unique_constraint(
