@@ -23,8 +23,8 @@ Create Date: 2014-10-10 11:28:08.645122
 revision = '17fd1b237aa3'
 down_revision = None
 
-from alembic import op
-import sqlalchemy as sa
+from alembic import op  # noqa: E402
+import sqlalchemy as sa  # noqa: E402
 
 
 def upgrade():
