@@ -16,11 +16,14 @@
 import abc
 import datetime
 
+from oslo_log import log as logging
+
 from oslo_config import cfg
-import six
 
 from cloudkitty import storage_state
 
+from werkzeug import exceptions as http_exceptions
+
 
 storage_opts = [
     cfg.IntOpt(
@@ -34,9 +37,10 @@ storage_opts = [
 CONF = cfg.CONF
 CONF.register_opts(storage_opts, 'storage')
 
+LOG = logging.getLogger(__name__)
 
-@six.add_metaclass(abc.ABCMeta)
-class BaseStorage(object):
+
+class BaseStorage(object, metaclass=abc.ABCMeta):
     """Abstract class for v2 storage objects."""
 
     def __init__(self, *args, **kwargs):
@@ -100,11 +104,9 @@ class BaseStorage(object):
         """
 
     @abc.abstractmethod
-    def total(self, groupby=None,
-              begin=None, end=None,
-              metric_types=None,
-              filters=None,
-              offset=0, limit=1000, paginate=True):
+    def total(self, groupby=None, begin=None, end=None, metric_types=None,
+              filters=None, custom_fields=None, offset=0, limit=1000,
+              paginate=True):
         """Returns a grouped total for given groupby.
 
         :param groupby: Attributes on which to group by. These attributes must
@@ -116,10 +118,14 @@ class BaseStorage(object):
         :type begin: datetime
         :param end: End date
         :type end: datetime
-        :param filters: Attributes to filter on. ex: {'flavor_id': '42'}
-        :type filters: dict
         :param metric_types: Metric type to filter on.
         :type metric_types: str or list
+        :param custom_fields: the custom fields that one desires to add in
+                              the summary reporting. Each driver must handle
+                              these values by themselves.
+        :type: custom_fields: list of strings
+        :param filters: Attributes to filter on. ex: {'flavor_id': '42'}
+        :type filters: dict
         :param offset: Offset for pagination
         :type offset: int
         :param limit: Maximum amount of elements to return
@@ -127,6 +133,7 @@ class BaseStorage(object):
         :param paginate: Defaults to True. If False, all found results
                          will be returned.
         :type paginate: bool
+
         :rtype: dict
 
         Returns a dict with the following format::
@@ -158,3 +165,35 @@ class BaseStorage(object):
     # NOTE(lpeschke): This is only kept for v1 storage backward compatibility
     def get_tenants(self, begin=None, end=None):
         return storage_state.StateManager().get_tenants(begin, end)
+
+    TIME_COMMANDS_MAP = {"d": "day_of_the_year", "w": "week_of_the_year",
+                         "m": "month", "y": "year"}
+
+    def parse_groupby_syntax_to_groupby_elements(self, groupbys):
+        if not groupbys:
+            LOG.debug("No groupby to process syntax.")
+            return groupbys
+
+        groupbys_parsed = []
+        for elem in groupbys:
+            if 'time' in elem:
+                time_command = elem.split('-')
+                number_of_parts = len(time_command)
+                if number_of_parts == 2:
+                    g = self.TIME_COMMANDS_MAP.get(time_command[1])
+                    if not g:
+                        raise http_exceptions.BadRequest(
+                            "Invalid groupby time option. There is no "
+                            "groupby processing for [%s]." % elem)
+
+                    LOG.debug("Replacing API groupby time command [%s] with "
+                              "internal groupby command [%s].", elem, g)
+                    elem = g
+
+                elif number_of_parts > 2:
+                    LOG.warning("The groupby [%s] command is not expected for "
+                                "storage backend [%s]. Therefore, we leave it "
+                                "as is.", elem, self)
+
+            groupbys_parsed.append(elem)
+        return groupbys_parsed
